@@ -6,9 +6,8 @@
 
 //! Detect the terminal application mdcat is running on.
 
-use crate::terminal::capabilities::iterm2::ITerm2;
+use crate::terminal::capabilities::iterm2::ITerm2Protocol;
 use crate::terminal::capabilities::*;
-use crate::terminal::AnsiStyle;
 use std::fmt::{Display, Formatter};
 
 /// A terminal application.
@@ -43,6 +42,10 @@ pub enum TerminalProgram {
     ///
     /// See <https://wezfurlong.org/wezterm/> for more information.
     WezTerm,
+    /// The built-in terminal in VSCode.
+    ///
+    /// Since version 1.80 it supports images with the iTerm2 protocol.
+    VSCode,
 }
 
 impl Display for TerminalProgram {
@@ -54,11 +57,24 @@ impl Display for TerminalProgram {
             TerminalProgram::Terminology => "Terminology",
             TerminalProgram::Kitty => "kitty",
             TerminalProgram::WezTerm => "WezTerm",
+            TerminalProgram::VSCode => "vscode",
         };
         write!(f, "{name}")
     }
 }
 
+/// Extract major and minor version from `$TERM_PROGRAM_VERSION`.
+///
+/// Return `None` if the variable doesn't exist, or has invalid contents, such as
+/// non-numeric parts, insufficient parts for a major.minor version, etc.
+fn get_term_program_major_minor_version() -> Option<(u16, u16)> {
+    let value = std::env::var("TERM_PROGRAM_VERSION").ok()?;
+    let mut parts = value.split('.').take(2);
+    let major = parts.next()?.parse().ok()?;
+    let minor = parts.next()?.parse().ok()?;
+    Some((major, minor))
+}
+
 impl TerminalProgram {
     fn detect_term() -> Option<Self> {
         match std::env::var("TERM").ok().as_deref() {
@@ -72,6 +88,12 @@ impl TerminalProgram {
         match std::env::var("TERM_PROGRAM").ok().as_deref() {
             Some("WezTerm") => Some(Self::WezTerm),
             Some("iTerm.app") => Some(Self::ITerm2),
+            Some("vscode")
+                if get_term_program_major_minor_version()
+                    .map_or(false, |version| (1, 80) <= version) =>
+            {
+                Some(Self::VSCode)
+            }
             _ => None,
         }
     }
@@ -114,8 +136,7 @@ impl TerminalProgram {
     /// Get the capabilities of this terminal emulator.
     pub fn capabilities(self) -> TerminalCapabilities {
         let ansi = TerminalCapabilities {
-            style: Some(StyleCapability::Ansi(AnsiStyle)),
-            links: Some(LinkCapability::Osc8(crate::terminal::osc::Osc8Links)),
+            style: Some(StyleCapability::Ansi),
             image: None,
             marks: None,
         };
@@ -123,16 +144,17 @@ impl TerminalProgram {
             TerminalProgram::Dumb => TerminalCapabilities::default(),
             TerminalProgram::Ansi => ansi,
             TerminalProgram::ITerm2 => ansi
-                .with_mark_capability(MarkCapability::ITerm2(ITerm2))
-                .with_image_capability(ImageCapability::ITerm2(ITerm2)),
+                .with_mark_capability(MarkCapability::ITerm2(ITerm2Protocol))
+                .with_image_capability(ImageCapability::ITerm2(ITerm2Protocol)),
             TerminalProgram::Terminology => {
                 ansi.with_image_capability(ImageCapability::Terminology(terminology::Terminology))
             }
-            TerminalProgram::Kitty => {
-                ansi.with_image_capability(ImageCapability::Kitty(self::kitty::KittyImages))
-            }
-            TerminalProgram::WezTerm => {
-                ansi.with_image_capability(ImageCapability::Kitty(self::kitty::KittyImages))
+            TerminalProgram::Kitty => ansi
+                .with_image_capability(ImageCapability::Kitty(self::kitty::KittyGraphicsProtocol)),
+            TerminalProgram::WezTerm => ansi
+                .with_image_capability(ImageCapability::Kitty(self::kitty::KittyGraphicsProtocol)),
+            TerminalProgram::VSCode => {
+                ansi.with_image_capability(ImageCapability::ITerm2(ITerm2Protocol))
             }
         }
     }
